# Extract from html

## How to use
Provided url of the page and html content, returns list of records with extractions.

`from kraken_extract_from_html import kraken_extract_from_html as k
`

`records = k.get(url, html)`